<?php
namespace ElementorBoxmessage\Widgets;

use \Elementor\Controls_Manager as Controls_Manager;
use \Elementor\Frontend;
use \Elementor\Group_Control_Border as Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography as Group_Control_Typography;
use \Elementor\Utils as Utils;
use \Elementor\Widget_Base as Widget_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Boxmessage
 *
 * Elementor widget for team vision
 *
 * @since 1.0.0
 */
class Boxmessage extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'boxmessage';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Box Message', 'boxmessageelementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-info-box';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'boxmessageelementor' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'boxmessageelementor' ),
			]
		);

		$this->add_control(
			'boxmessagge_type',
			[
				'label' => esc_html__( 'Type Box Message', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'	=> esc_html__( 'Default', 'boxmessageelementor' ),
					'custom' 	=> esc_html__( 'Custom', 'boxmessageelementor' )				
				]
			]
		);	

		$this->add_control(
			'boxmessagge_default_type',
			[
				'label' => esc_html__( 'Type Default Message', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'bme_message-info',
				'options' => [
					'bme_message-info'		=> esc_html__( 'Info', 'boxmessageelementor' ),
					'bme_message-warning' 	=> esc_html__( 'Alert', 'boxmessageelementor' ),				
					'bme_message-success' 	=> esc_html__( 'Success', 'boxmessageelementor' ),				
					'bme_message-danger' 		=> esc_html__( 'Error', 'boxmessageelementor' )				
				],
				'condition'	=> [
					'boxmessagge_type'	=> 'default'
				]
			]
		);	

		$this->add_control(
			'boxmessagge_default_rtl',
			[
				'label' => esc_html__( 'RTL', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'off',
				'options' => [
					'off'	=> esc_html__( 'Off', 'boxmessageelementor' ),
					'on' 	=> esc_html__( 'On', 'boxmessageelementor' )			
				],
				'condition'	=> [
					'boxmessagge_type'	=> 'default'
				]
			]
		);

		$this->add_control(
			'boxmessagge_default_style',
			[
				'label' => esc_html__( 'Style', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'vc_alert_rounded',
				'options' => [
					'vc_alert_rounded'			=> esc_html__( 'Rounded', 'boxmessageelementor' ),
					'vc_alert_square' 			=> esc_html__( 'Square', 'boxmessageelementor' ),				
					'vc_alert_round' 			=> esc_html__( 'Round', 'boxmessageelementor' ),				
					'vc_alert_outlined' 		=> esc_html__( 'Outlined', 'boxmessageelementor' ),				
					'vc_alert_3d' 				=> esc_html__( '3D', 'boxmessageelementor' ),				
					'vc_alert_square_outlined' 	=> esc_html__( 'Square Outlined', 'boxmessageelementor' )				
				]
			]
		);

		$this->add_control(
			'boxmessagge_custom_icon',
			[
				'label' => esc_html__( 'Icon', 'boxmessageelementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
						'value' => 'fas fa-star',
						'library' => 'solid',
				],
				'condition'	=> [
					'boxmessagge_type'	=> 'custom'
				]
			]
		);

		$this->add_control(
			'boxmessagge_custom_icon_float',
			[
				'label' => esc_html__( 'Icon Float', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left'			=> esc_html__( 'Left', 'boxmessageelementor' ),
					'right' 		=> esc_html__( 'Right', 'boxmessageelementor' ),				
					'none' 			=> esc_html__( 'None', 'boxmessageelementor' )				
				],
				'condition'	=> [
					'boxmessagge_type'	=> 'custom'
				]
			]
		);

		$this->add_control(
			'boxmessagge_text',
			[
				'label' => esc_html__( 'Text Message', 'elementor-calltoaction' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => ''
			]
		);

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_animation',
			[
				'label' => esc_html__( 'Animations', 'boxmessageelementor' )
			]
		);
		
		$this->add_control(
			'addon_animate',
			[
				'label' => esc_html__( 'Animate', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'off',
				'options' => [
					'off'	=> 'Off',
					'on' 	=> 'On'					
				]
			]
		);		

		$this->add_control(
			'effect',
			[
				'label' => esc_html__( 'Animate Effects', 'boxmessageelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fade-in',
				'options' => [
							'fade-in'			=> esc_html__( 'Fade In', 'boxmessageelementor' ),
							'fade-in-up' 		=> esc_html__( 'fade in up', 'boxmessageelementor' ),					
							'fade-in-down' 		=> esc_html__( 'fade in down', 'boxmessageelementor' ),					
							'fade-in-left' 		=> esc_html__( 'fade in Left', 'boxmessageelementor' ),					
							'fade-in-right' 	=> esc_html__( 'fade in Right', 'boxmessageelementor' ),					
							'fade-out'			=> esc_html__( 'Fade In', 'boxmessageelementor' ),
							'fade-out-up' 		=> esc_html__( 'Fade Out up', 'boxmessageelementor' ),					
							'fade-out-down' 	=> esc_html__( 'Fade Out down', 'boxmessageelementor' ),					
							'fade-out-left' 	=> esc_html__( 'Fade Out Left', 'boxmessageelementor' ),					
							'fade-out-right' 	=> esc_html__( 'Fade Out Right', 'boxmessageelementor' ),
							'bounce-in'			=> esc_html__( 'Bounce In', 'boxmessageelementor' ),
							'bounce-in-up' 		=> esc_html__( 'Bounce in up', 'boxmessageelementor' ),					
							'bounce-in-down' 	=> esc_html__( 'Bounce in down', 'boxmessageelementor' ),					
							'bounce-in-left' 	=> esc_html__( 'Bounce in Left', 'boxmessageelementor' ),					
							'bounce-in-right' 	=> esc_html__( 'Bounce in Right', 'boxmessageelementor' ),					
							'bounce-out'		=> esc_html__( 'Bounce In', 'boxmessageelementor' ),
							'bounce-out-up' 	=> esc_html__( 'Bounce Out up', 'boxmessageelementor' ),					
							'bounce-out-down' 	=> esc_html__( 'Bounce Out down', 'boxmessageelementor' ),					
							'bounce-out-left' 	=> esc_html__( 'Bounce Out Left', 'boxmessageelementor' ),					
							'bounce-out-right' 	=> esc_html__( 'Bounce Out Right', 'boxmessageelementor' ),	
							'zoom-in'			=> esc_html__( 'Zoom In', 'boxmessageelementor' ),
							'zoom-in-up' 		=> esc_html__( 'Zoom in up', 'boxmessageelementor' ),					
							'zoom-in-down' 		=> esc_html__( 'Zoom in down', 'boxmessageelementor' ),					
							'zoom-in-left' 		=> esc_html__( 'Zoom in Left', 'boxmessageelementor' ),					
							'zoom-in-right' 	=> esc_html__( 'Zoom in Right', 'boxmessageelementor' ),					
							'zoom-out'			=> esc_html__( 'Zoom In', 'boxmessageelementor' ),
							'zoom-out-up' 		=> esc_html__( 'Zoom Out up', 'boxmessageelementor' ),					
							'zoom-out-down' 	=> esc_html__( 'Zoom Out down', 'boxmessageelementor' ),					
							'zoom-out-left' 	=> esc_html__( 'Zoom Out Left', 'boxmessageelementor' ),					
							'zoom-out-right' 	=> esc_html__( 'Zoom Out Right', 'boxmessageelementor' ),
							'flash' 			=> esc_html__( 'Flash', 'boxmessageelementor' ),
							'strobe'			=> esc_html__( 'Strobe', 'boxmessageelementor' ),
							'shake-x'			=> esc_html__( 'Shake X', 'boxmessageelementor' ),
							'shake-y'			=> esc_html__( 'Shake Y', 'boxmessageelementor' ),
							'bounce' 			=> esc_html__( 'Bounce', 'boxmessageelementor' ),
							'tada'				=> esc_html__( 'Tada', 'boxmessageelementor' ),
							'rubber-band'		=> esc_html__( 'Rubber Band', 'boxmessageelementor' ),
							'swing' 			=> esc_html__( 'Swing', 'boxmessageelementor' ),
							'spin'				=> esc_html__( 'Spin', 'boxmessageelementor' ),
							'spin-reverse'		=> esc_html__( 'Spin Reverse', 'boxmessageelementor' ),
							'slingshot'			=> esc_html__( 'Slingshot', 'boxmessageelementor' ),
							'slingshot-reverse'	=> esc_html__( 'Slingshot Reverse', 'boxmessageelementor' ),
							'wobble'			=> esc_html__( 'Wobble', 'boxmessageelementor' ),
							'pulse' 			=> esc_html__( 'Pulse', 'boxmessageelementor' ),
							'pulsate'			=> esc_html__( 'Pulsate', 'boxmessageelementor' ),
							'heartbeat'			=> esc_html__( 'Heartbeat', 'boxmessageelementor' ),
							'panic' 			=> esc_html__( 'Panic', 'boxmessageelementor' )				
				],
				'condition'	=> [
					'addon_animate'	=> 'on'
				]
			]
		);			

		$this->add_control(
			'delay',
			[
				'label' => esc_html__( 'Animate Delay (ms)', 'boxmessageelementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '1000',
				'condition'	=> [
					'addon_animate'	=> 'on'
				]
			]
		);	
		
		$this->end_controls_section();


		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'boxmessageelementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'boxmessagge_custom_text_size',
			[
				'label' => esc_html__( 'Text Size (px)', 'boxmessageelementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '14px'
			]
		);

		$this->add_control(
			'boxmessagge_custom_size',
			[
				'label' => esc_html__( 'Icon Size (px)', 'boxmessageelementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '20px'
			]
		);	

		$this->add_control(
			'boxmessagge_custom_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'boxmessageelementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FFFFFF',
				'condition'	=> [
					'boxmessagge_type'	=> 'custom'
				]
			]
		);

		$this->add_control(
			'boxmessagge_custom_margin',
			[
				'label' => esc_html__( 'Icon Margin', 'boxmessageelementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '2px',
				'condition'	=> [
					'boxmessagge_type'	=> 'custom'
				]
			]
		);	

		$this->add_control(
			'boxmessagge_custom_padding',
			[
				'label' => esc_html__( 'Icon Padding', 'boxmessageelementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '23px'
			]
		);	

		$this->add_control(
			'boxmessagge_custom_background_color',
			[
				'label' => esc_html__( 'Background Color', 'boxmessageelementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#23a455',
				'condition'	=> [
					'boxmessagge_type'	=> 'custom'
				]
			]
		);

		$this->add_control(
			'boxmessagge_custom_background_border_3d_color',
			[
				'label' => esc_html__( 'Border Color only For 3d Box', 'boxmessageelementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FC615D',
				'condition'	=> [
					'boxmessagge_type'	=> 'custom'
				]
			]
		);

		$this->end_controls_section();
		
	}

	 
	 /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		static $instance = 0;
		$instance++;		
		$settings = $this->get_settings_for_display();
		
        $boxmessagge_type									= esc_html($settings['boxmessagge_type']);		
        $boxmessagge_default_type							= esc_html($settings['boxmessagge_default_type']);		
		$boxmessagge_default_style							= esc_html($settings['boxmessagge_default_style']);
		$boxmessagge_default_rtl							= esc_html($settings['boxmessagge_default_rtl']);
        $boxmessagge_custom_text_size						= esc_html($settings['boxmessagge_custom_text_size']);
        $boxmessagge_custom_size							= esc_html($settings['boxmessagge_custom_size']);
        $boxmessagge_custom_icon_float						= esc_html($settings['boxmessagge_custom_icon_float']);
		$boxmessagge_custom_icon_color						= esc_html($settings['boxmessagge_custom_icon_color']);
		$boxmessagge_custom_background_color				= esc_html($settings['boxmessagge_custom_background_color']);
		$boxmessagge_custom_margin							= esc_html($settings['boxmessagge_custom_margin']);
		$boxmessagge_custom_padding							= esc_html($settings['boxmessagge_custom_padding']);		
		$boxmessagge_custom_background_border_3d_color		= esc_html($settings['boxmessagge_custom_background_border_3d_color']);		
		$boxmessagge_text									= esc_html($settings['boxmessagge_text']);		
		
		// Animations
		$addon_animate			= esc_html($settings['addon_animate']);
		$effect					= esc_html($settings['effect']);
		$delay					= esc_html($settings['delay']);
		
		wp_enqueue_style( 'animations' );
		wp_enqueue_script( 'appear' );			
		wp_enqueue_script( 'animate' );
		wp_enqueue_style( 'elementor-icons' );
		wp_enqueue_style( 'font-awesome' );	
		
	
	// DEFAULT
	if($boxmessagge_type == 'default') {
			echo '<style type="text/css">
							.boxmessage-'.esc_html($instance).' .boxmessage_text {
								font-size:'.esc_html($boxmessagge_custom_text_size).';
							}
							.boxmessage-'.esc_html($instance).' i {
								font-size:'.esc_html($boxmessagge_custom_size).';
								padding:'.esc_html($boxmessagge_custom_padding).';
							}</style>';		
		if($addon_animate == 'on') {
			echo '<div class="boxmessage-'.esc_html($instance).' bme_message bme_content_element '.esc_html($boxmessagge_default_type).' boxmessage-rtl-'.esc_html($boxmessagge_default_rtl).' '.esc_html($boxmessagge_default_style).' animate-in" data-anim-type="'.esc_html($effect).'" data-anim-delay="'.esc_html($delay).'">
							<div class="boxmessage_text"><div class="icon-container"><i class="fa ';
							
							if($boxmessagge_default_type == 'bme_message-info') {	
								echo 'fa-info-circle';								
							}
							if($boxmessagge_default_type == 'bme_message-warning') {	
								echo 'fa-exclamation-triangle';								
							}
							if($boxmessagge_default_type == 'bme_message-success') {	
								echo 'fa-check';								
							}
							if($boxmessagge_default_type == 'bme_message-danger') {	
								echo 'fa-times';								
							}							
							
							echo '"></i></div><div class="message-text">'.esc_html($boxmessagge_text).'</div><div class="clearfix"></div></div>
						</div>';
		} else {
			echo '<div class="boxmessage-'.esc_html($instance).' bme_message bme_content_element '.esc_html($boxmessagge_default_type).' boxmessage-rtl-'.esc_html($boxmessagge_default_rtl).' '.esc_html($boxmessagge_default_style).'">
							<div class="boxmessage_text"><div class="icon-container"><i class="fa ';
							
							if($boxmessagge_default_type == 'bme_message-info') {	
								echo 'fa-info-circle';								
							}
							if($boxmessagge_default_type == 'bme_message-warning') {	
								echo 'fa-exclamation-triangle';								
							}
							if($boxmessagge_default_type == 'bme_message-success') {	
								echo 'fa-check';								
							}
							if($boxmessagge_default_type == 'bme_message-danger') {	
								echo 'fa-times';								
							}							
							
							echo '"></i></div><div class="message-text">'.esc_html($boxmessagge_text).'</div><div class="clearfix"></div></div>
						</div>';				
		}
		
	}
	
	// CUSTOM
	if($boxmessagge_type == 'custom') {
		if($addon_animate == 'on') {
			echo '<style type="text/css">
							.boxmessage-'.esc_html($instance).' .boxmessage_text {
								background:none!important;
								text-shadow:0 0 0;
								color:'.esc_html($boxmessagge_custom_icon_color).';
								font-size:'.esc_html($boxmessagge_custom_text_size).';
							}
							.boxmessage-'.esc_html($instance).' {
								background-color:'.esc_html($boxmessagge_custom_background_color).'!important;							
								border-color:'.esc_html($boxmessagge_custom_background_color).'!important;
																						
							}
							.boxmessage-'.esc_html($instance).' i {
								float:'.esc_html($boxmessagge_custom_icon_float).';
								margin:'.esc_html($boxmessagge_custom_margin).';
								padding:'.esc_html($boxmessagge_custom_padding).';
								color:'.esc_html($boxmessagge_custom_icon_color).';
								font-size:'.esc_html($boxmessagge_custom_size).';
							}';
			if($boxmessagge_default_style == 'vc_alert_3d') {				
					echo '.boxmessage-'.esc_html($instance).' {
								box-shadow:0 5px 0 '.esc_html($boxmessagge_custom_background_border_3d_color).';
					}';
			}			
			echo	'</style>';
			
			echo '<div class="boxmessage-'.esc_html($instance).' bme_message bme_content_element '.esc_html($boxmessagge_default_style).' animate-in" data-anim-type="'.esc_html($effect).'" data-anim-delay="'.esc_html($delay).'">
								<div class="boxmessage_text">';
								
								\Elementor\Icons_Manager::render_icon( $settings['boxmessagge_custom_icon'], [ 'aria-hidden' => 'true' ] );
								
								echo esc_html($boxmessagge_text).'</div>
						</div>';
		} else {
			echo '<style type="text/css">
							.boxmessage-'.esc_html($instance).' .boxmessage_text {
								background:none!important;
								text-shadow:0 0 0;
								color:'.esc_html($boxmessagge_custom_icon_color).';
								font-size:'.esc_html($boxmessagge_custom_text_size).';
							}
							.boxmessage-'.esc_html($instance).' {
								background-color:'.esc_html($boxmessagge_custom_background_color).'!important;							
								border-color:'.esc_html($boxmessagge_custom_background_color).'!important;														
							}
							.boxmessage-'.esc_html($instance).' i {
								float:'.esc_html($boxmessagge_custom_icon_float).';
								margin:'.esc_html($boxmessagge_custom_margin).';
								padding:'.esc_html($boxmessagge_custom_padding).';
								color:'.esc_html($boxmessagge_custom_icon_color).';
								font-size:'.esc_html($boxmessagge_custom_size).';
							}';
			if($boxmessagge_default_style == 'vc_alert_3d') {				
					echo '.boxmessage-'.esc_html($instance).' {
								box-shadow:0 5px 0 '.esc_html($boxmessagge_custom_background_border_3d_color).';
					}';
			}							
			echo '</style>';

			echo '<div class="boxmessage-'.esc_html($instance).' bme_message bme_content_element '.esc_html($boxmessagge_default_style).'">
						<div class="boxmessage_text">';
								
					    \Elementor\Icons_Manager::render_icon( $settings['boxmessagge_custom_icon'], [ 'aria-hidden' => 'true' ] );
								
						echo esc_html($boxmessagge_text).'</div>
			</div>';		
		}
	}

		
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}
